@@ -2,7 +2,7 @@
 /* clp.c - Complete source code for CLP.
  * This file is part of CLP, the command line parser package.
  *
- * Copyright (c) 1997-2021 Eddie Kohler, ekohler@gmail.com
+ * Copyright (c) 1997-2024 Eddie Kohler, ekohler@gmail.com
  *
  * CLP is free software. It is distributed under the GNU General Public
  * License, Version 2, or, alternatively and at your discretion, under the
@@ -2132,8 +2132,7 @@ Clp_vbsprintf(Clp_Parser *clp, Clp_BuildString *bs,
           case 'd': {
               int d = va_arg(val, int);
               if (ENSURE_BUILD_STRING(bs, 32)) {
-                  snprintf(bs->pos, 32, "%d", d);
-                  bs->pos = strchr(bs->pos, 0);
+                  bs->pos += snprintf(bs->pos, 32, "%d", d);
               }
               break;
           }
