@@ -1,5 +1,5 @@
 /* xform.c - Image transformation functions for gifsicle.
-   Copyright (C) 1997-2021 Eddie Kohler, ekohler@gmail.com
+   Copyright (C) 1997-2024 Eddie Kohler, ekohler@gmail.com
    This file is part of gifsicle.
 
    Gifsicle is free software. It is distributed under the GNU Public License,
@@ -262,18 +262,18 @@ crop_image(Gif_Image* gfi, Gt_Frame* fr, int preserve_total_crop)
             gfi->img[j] = old_img[c.y + j] + c.x;
         gfi->img[c.h] = 0;
         Gif_DeleteArray(old_img);
+        gfi->left += c.x - fr->left_offset;
+        gfi->top += c.y - fr->top_offset;
         gfi->width = c.w;
         gfi->height = c.h;
-    } else if (preserve_total_crop)
+    } else if (preserve_total_crop) {
         Gif_MakeImageEmpty(gfi);
-    else {
+    } else {
         Gif_DeleteArray(gfi->img);
         gfi->img = 0;
         gfi->width = gfi->height = 0;
     }
 
-    gfi->left += c.x - fr->left_offset;
-    gfi->top += c.y - fr->top_offset;
     return gfi->img != 0;
 }
 
